==> ejc-bfyjerp-impl-3.0.0-20250427.070044-209-sources.jar: com/ejianc/business/oa/service/impl/MonInsuranceServiceImpl.java <==
package com.ejianc.business.oa.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.ejianc.business.finance.utils.DateUtil;
import com.ejianc.business.oa.bean.InsurancePaymentApplyEntity;
import com.ejianc.business.oa.service.IInsurancePaymentApplyService;
import com.ejianc.business.oa.vo.MonInsuranceVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.oa.mapper.MonInsuranceMapper;
import com.ejianc.business.oa.bean.MonInsuranceEntity;
import com.ejianc.business.oa.service.IMonInsuranceService;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * 月度保险明细
 * 
 * @author generator
 * 
 */
@Service("monInsuranceService")
public class MonInsuranceServiceImpl extends BaseServiceImpl<MonInsuranceMapper, MonInsuranceEntity> implements IMonInsuranceService{
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private IInsurancePaymentApplyService applyService;
    @Override
    public void generateMothInsurance() {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.in("bill_state", Arrays.asList(1,3));
        queryWrapper.eq("dr", 0);
        queryWrapper.apply("(DATE_FORMAT(CURRENT_DATE,'%Y-%m') >=DATE_FORMAT(end_date,'%Y-%m') OR  end_date IS NULL)");
        List<InsurancePaymentApplyEntity> list = applyService.list(queryWrapper);
        if(CollectionUtils.isEmpty(list)) {
            logger.info("---------------------未查询到保险申请单，任务执行结束---------------------");
            return;
        }
        List<MonInsuranceVO> saveList = new ArrayList();
        for (InsurancePaymentApplyEntity insuranceEntity : list) {
            MonInsuranceVO monInsuranceVO = new MonInsuranceVO();
            monInsuranceVO.setHumanType(null!=insuranceEntity.getHumanType()?insuranceEntity.getHumanType().toString():null);
            monInsuranceVO.setHumanTypeName(insuranceEntity.getHumanTypeName());
            monInsuranceVO.setPersonId(insuranceEntity.getPersonId());
            monInsuranceVO.setPersonName(insuranceEntity.getPersonName());
            monInsuranceVO.setDeptId(insuranceEntity.getDeptId());
            monInsuranceVO.setDeptName(insuranceEntity.getDeptName());
            monInsuranceVO.setInsuredType(insuranceEntity.getInsuredType());
            monInsuranceVO.setInsuredTypeName(insuranceEntity.getInsuredTypeName());
            monInsuranceVO.setFeesBorne(insuranceEntity.getFeesBorne());
            monInsuranceVO.setFeesBorneName(insuranceEntity.getFeesBorneName());
            monInsuranceVO.setCompanyTotalMnyMonth(insuranceEntity.getCompanyTotalMnyMonth());
            monInsuranceVO.setPersonTotalMnyMonth(insuranceEntity.getPersonTotalMnyMonth());
            monInsuranceVO.setTotalMnyMonth(insuranceEntity.getTotalMnyMonth());
            monInsuranceVO.setUpDown("0");
            monInsuranceVO.setBillDate(new Date());
            monInsuranceVO.setYear(DateUtil.format(new Date(), "yyyy"));
            monInsuranceVO.setMonth(DateUtil.format(new Date(), "MM"));
            monInsuranceVO.setTenantId(888888l);
            monInsuranceVO.setInsuranceId(insuranceEntity.getId());
            saveList.add(monInsuranceVO);
        }
        super.saveOrUpdateBatch(BeanMapper.mapList(saveList,MonInsuranceEntity.class) ,saveList.size(),false);
    }
}

==> ejc-bfyjerp-impl-3.0.0-20250717.081502-241-sources.jar: com/ejianc/business/oa/service/impl/MonInsuranceServiceImpl.java <==
package com.ejianc.business.oa.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.ejianc.business.finance.utils.DateUtil;
import com.ejianc.business.oa.bean.InsurancePaymentApplyEntity;
import com.ejianc.business.oa.service.IInsurancePaymentApplyService;
import com.ejianc.business.oa.vo.MonInsuranceVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.oa.mapper.MonInsuranceMapper;
import com.ejianc.business.oa.bean.MonInsuranceEntity;
import com.ejianc.business.oa.service.IMonInsuranceService;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * 月度保险明细
 * 
 * @author generator
 * 
 */
@Service("monInsuranceService")
public class MonInsuranceServiceImpl extends BaseServiceImpl<MonInsuranceMapper, MonInsuranceEntity> implements IMonInsuranceService{
    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private IInsurancePaymentApplyService applyService;
    @Override
    public void generateMothInsurance() {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.in("bill_state", Arrays.asList(1,3));
        queryWrapper.eq("dr", 0);
        queryWrapper.apply("(DATE_FORMAT(CURRENT_DATE,'%Y-%m') <=DATE_FORMAT(end_date,'%Y-%m') OR  end_date IS NULL)");
        List<InsurancePaymentApplyEntity> list = applyService.list(queryWrapper);
        if(CollectionUtils.isEmpty(list)) {
            logger.info("---------------------未查询到保险申请单，任务执行结束---------------------");
            return;
        }
        List<MonInsuranceVO> saveList = new ArrayList();
        for (InsurancePaymentApplyEntity insuranceEntity : list) {
            MonInsuranceVO monInsuranceVO = new MonInsuranceVO();
            monInsuranceVO.setHumanType(null!=insuranceEntity.getHumanType()?insuranceEntity.getHumanType().toString():null);
            monInsuranceVO.setHumanTypeName(insuranceEntity.getHumanTypeName());
            monInsuranceVO.setPersonId(insuranceEntity.getPersonId());
            monInsuranceVO.setPersonName(insuranceEntity.getPersonName());
            monInsuranceVO.setDeptId(insuranceEntity.getDeptId());
            monInsuranceVO.setDeptName(insuranceEntity.getDeptName());
            monInsuranceVO.setInsuredType(insuranceEntity.getInsuredType());
            monInsuranceVO.setInsuredTypeName(insuranceEntity.getInsuredTypeName());
            monInsuranceVO.setFeesBorne(insuranceEntity.getFeesBorne());
            monInsuranceVO.setFeesBorneName(insuranceEntity.getFeesBorneName());
            monInsuranceVO.setCompanyTotalMnyMonth(insuranceEntity.getCompanyTotalMnyMonth());
            monInsuranceVO.setPersonTotalMnyMonth(insuranceEntity.getPersonTotalMnyMonth());
            monInsuranceVO.setTotalMnyMonth(insuranceEntity.getTotalMnyMonth());
            monInsuranceVO.setUpDown("0");
            monInsuranceVO.setBillDate(new Date());
            monInsuranceVO.setYear(DateUtil.format(new Date(), "yyyy"));
            monInsuranceVO.setMonth(DateUtil.format(new Date(), "MM"));
            monInsuranceVO.setTenantId(888888l);
            monInsuranceVO.setInsuranceId(insuranceEntity.getId());
            saveList.add(monInsuranceVO);
        }
        super.saveOrUpdateBatch(BeanMapper.mapList(saveList,MonInsuranceEntity.class) ,saveList.size(),false);
    }
}
